@@ -1,6 +1,6 @@
 import re
 from json import dumps
-from typing import Any, Iterable, Optional, Union
+from typing import Any, Iterable, Optional
 
 from pyquery import PyQuery
 
@@ -11,12 +11,25 @@ from easydata.queries.base import QuerySearch
 class ReQuery(QuerySearch):
     def __init__(
         self,
-        query: Union[str, bytes],
-        flag: int = re.DOTALL,
+        query: str,
+        dotall: bool = True,
+        ignore_case: bool = False,
         bytes_to_string_decode: str = "utf-8",
     ):
 
-        self._query = re.compile(query, flag)
+        if query and query == "::all":
+            raise ValueError("Regex pattern is required beside ::all!")
+
+        if query and query.endswith("::all"):
+            query = query.split("::all")[0]
+
+            self._all = True
+        else:
+            self._all = False
+
+        self._query = query
+        self._dotall = dotall
+        self._ignore_case = ignore_case
         self._bytes_to_string_decode = bytes_to_string_decode
 
     def _parse(
@@ -24,6 +37,9 @@ class ReQuery(QuerySearch):
         data: Any,
     ):
 
+        if self._all:
+            return list(self._iter_parse(data))
+
         for result in self._iter_parse(data):
             return result
 
@@ -32,7 +48,15 @@ class ReQuery(QuerySearch):
         data: Any,
     ) -> Iterable[Any]:
 
-        results = re.finditer(self._query, data)
+        flags = 0
+
+        if self._dotall:
+            flags = re.DOTALL
+
+        if self._ignore_case:
+            flags = flags | re.IGNORECASE if flags else re.IGNORECASE
+
+        results = re.finditer(self._query, data, flags)
 
         for result in results:
             yield result.group(1)
@@ -47,7 +71,7 @@ class ReQuery(QuerySearch):
             data = data[source]
 
         if isinstance(data, PyQuery):
-            data = data.html()
+            data = data.outer_html()
 
         if isinstance(data, (dict, list)):
             data = dumps(data)
@@ -56,6 +80,9 @@ class ReQuery(QuerySearch):
             data = data.decode(self._bytes_to_string_decode)
 
         if not isinstance(data, str):
-            raise TypeError("Provided data must be string in order to make re search")
+            raise TypeError(
+                "Provided data must type of string, DataBag, PyQuery, dict, list "
+                "or bytes",
+            )
 
         return data
