@@ -10,13 +10,13 @@ def test_jp_query_get():
     assert jp_query.get(jd, "data") == "smartphone"
 
 
-def test_jp_query_get_iter():
+def test_jp_query_get_multi():
     jp_query = jp("images[].zoom")
 
     expected_image_list = [
         "https://demo.com/imgs/1-zoom.jpg",
         "https://demo.com/imgs/2-zoom.jpg",
     ]
-    image_list = [i for i in jp_query.get_iter(jd, "data")]
+    image_list = [i for i in jp_query.get(jd, "data")]
 
     assert image_list == expected_image_list
